@@ -60,7 +60,7 @@ union_resolve(JSContext       *context,
               bool            *resolved)
 {
     Union *priv;
-    g_autofree char *name = NULL;
+    char *name = NULL;
 
     if (!gjs_get_string_id(context, id, &name)) {
         *resolved = false;
@@ -71,8 +71,10 @@ union_resolve(JSContext       *context,
     gjs_debug_jsprop(GJS_DEBUG_GBOXED, "Resolve prop '%s' hook obj %p priv %p",
                      name, obj.get(), priv);
 
-    if (priv == NULL)
+    if (priv == NULL) {
+        g_free(name);
         return false; /* wrong class */
+    }
 
     if (priv->gboxed != NULL) {
         /* We are an instance, not a prototype, so look for
@@ -83,6 +85,7 @@ union_resolve(JSContext       *context,
          * hooks, not this resolve hook.
          */
         *resolved = false;
+        g_free(name);
         return true;
     }
 
@@ -112,6 +115,7 @@ union_resolve(JSContext       *context,
                                     g_registered_type_info_get_g_type(priv->info),
                                     method_info) == NULL) {
                 g_base_info_unref( (GIBaseInfo*) method_info);
+                g_free(name);
                 return false;
             }
 
@@ -125,6 +129,7 @@ union_resolve(JSContext       *context,
         *resolved = false;
     }
 
+    g_free(name);
     return true;
 }
 
